Package: nestedLogit
Title: Nested Dichotomy Logistic Regression Models
Version: 0.4.2
Date: 2026-05-27
Authors@R: c(
    person("John", "Fox", , "jfox@mcmaster.ca", role = "aut",
           comment = c(ORCID = "0000-0002-1196-8012")),
    person("Michael", "Friendly", , "friendly@yorku.ca", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-3237-0941")),
    person("Achim", "Zeileis", , "Achim.Zeileis@uibk.ac.at", role = "ctb",
           comment = c(ORCID = "0000-0003-0918-3766"))
  )
Description: Provides functions for specifying and fitting nested
    dichotomy logistic regression models for a multi-category response and
    methods for summarising and plotting those models.  Nested dichotomies are
    statistically independent, and hence provide an additive decomposition
    of tests for the overall 'polytomous' response.  When the dichotomies
    make sense substantively, this method can be a simpler alternative to
    the standard 'multinomial' logistic model which compares response
    categories to a reference level.  See: J. Fox (2016), "Applied
    Regression Analysis and Generalized Linear Models", 3rd Ed., ISBN
    1452205663.
License: GPL (>= 2)
URL: https://github.com/friendly/nestedLogit,
        https://friendly.github.io/nestedLogit/
BugReports: https://github.com/friendly/nestedLogit/issues
Depends: R (>= 4.1.0)
Imports: broom, car, dplyr, effects, graphics, grDevices, stats,
        stringr, tibble, scales
Suggests: AER, carData, equatiomatic, DescTools, geomtextpath, ggplot2,
        ggeffects, here, insight, lobstr, knitr, nnet, parameters,
        performance, rmarkdown, see, spelling, testthat, tidyr, MASS,
        VGAM, mlogit, vcd
VignetteBuilder: knitr, rmarkdown
Encoding: UTF-8
Language: en-US
LazyData: TRUE
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-28 13:19:08 UTC; friendly
Author: John Fox [aut] (ORCID: <https://orcid.org/0000-0002-1196-8012>),
  Michael Friendly [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3237-0941>),
  Achim Zeileis [ctb] (ORCID: <https://orcid.org/0000-0003-0918-3766>)
Maintainer: Michael Friendly <friendly@yorku.ca>
Repository: CRAN
Date/Publication: 2026-05-28 14:10:01 UTC
Built: R 4.5.2; ; 2026-05-28 16:22:25 UTC; unix
