# Generated by roxygen2: do not edit by hand

S3method(Anova,nestedLogit)
S3method(RSQ,multinom)
S3method(RSQ,nestedLogit)
S3method(RSQ,polr)
S3method(anova,nestedLogit)
S3method(as.character,dichotomies)
S3method(as.data.frame,predictDichotomies)
S3method(as.data.frame,predictNestedLogit)
S3method(as.dichotomies,matrix)
S3method(as.matrix,continuationDichotomies)
S3method(as.matrix,dichotomies)
S3method(as.tree,continuationDichotomies)
S3method(as.tree,dichotomies)
S3method(broom::glance,nestedLogit)
S3method(broom::tidy,nestedLogit)
S3method(car::Anova,nestedLogit)
S3method(car::linearHypothesis,nestedLogit)
S3method(coef,nestedLogit)
S3method(confint,predictNestedLogit)
S3method(createDichotomies,default)
S3method(createDichotomies,dichotomies)
S3method(createDichotomies,list)
S3method(effects::Effect,nestedLogit)
S3method(equatiomatic::extract_eq,nestedLogit)
S3method(fitted,nestedLogit)
S3method(linearHypothesis,nestedLogit)
S3method(logLik,nestedLogit)
S3method(models,nestedLogit)
S3method(plot,nestedLogit)
S3method(predict,nestedLogit)
S3method(print,Anova.nestedLogit)
S3method(print,RSQ.multinom)
S3method(print,RSQ.nestedLogit)
S3method(print,RSQ.polr)
S3method(print,anova.nestedLogit)
S3method(print,dichotomies)
S3method(print,nestedLogit)
S3method(print,nestedLogit_equations)
S3method(print,predictDichotomies)
S3method(print,predictNestedLogit)
S3method(print,summary.nestedLogit)
S3method(stats::logLik,nestedLogit)
S3method(summary,nestedLogit)
S3method(update,nestedLogit)
S3method(vcov,nestedLogit)
export(RSQ)
export(as.dichotomies)
export(as.tree)
export(continuationLogits)
export(dichotomy)
export(logits)
export(models)
export(nestedLogit)
importFrom(broom,glance)
importFrom(broom,tidy)
importFrom(car,Anova)
importFrom(car,linearHypothesis)
importFrom(dplyr,bind_cols)
importFrom(dplyr,select)
importFrom(effects,Effect)
importFrom(grDevices,adjustcolor)
importFrom(grDevices,palette)
importFrom(graphics,arrows)
importFrom(graphics,axis)
importFrom(graphics,box)
importFrom(graphics,matplot)
importFrom(graphics,polygon)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(scales,hue_pal)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,anova)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,confint)
importFrom(stats,fitted)
importFrom(stats,formula)
importFrom(stats,glm)
importFrom(stats,logLik)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,na.omit)
importFrom(stats,pchisq)
importFrom(stats,predict)
importFrom(stats,qnorm)
importFrom(stats,setNames)
importFrom(stats,update)
importFrom(stringr,str_remove)
importFrom(tibble,rownames_to_column)
importFrom(utils,capture.output)
