As befits a model-fitting function, the package defines a nearly complete set of methods for  `"nestedLogit"` objects:

* `print()` and `summary()` print the results for each of the submodels.
* `update()` re-fits the model, allowing changes to the model `formula`, `data`, `subset`, and `contrasts` arguments.
* `coef()` returns the coefficients for the predictors in each dichotomy.
* `vcov()` returns the variance-covariance matrix of the coefficients
* `predict()` computes predicted probabilities for the response categories, either for the cases in the data, which is equivalent to `fitted()`, or for arbitrary combinations of the predictors; the latter is useful for producing plots to aid interpretation.
* `confint()` calculates confidence intervals for the predicted probabilities or predicted logits.
* `as.data.frame()` method for predicted probabilities and logits converts these to long format for use with `ggplot2`.
* `glance()` and `tidy()` are extensions of `broom::glance.glm()` and `broom::tidy.glm()` to obtain compact summaries of a `"nestedLogit"` model object.
* `plot()` provides basic plots of the predicted probabilities over a range of values of the predictor variables.
* `models()` is an extractor function for the binary logit models in the `"nestedLogit"` object
* `Effect()` calculates marginal effects collapsed over some variable(s) for the purpose of making effect plots.

These functions are supplemented by various methods for testing hypotheses about and comparing nested-logit models:

* `anova()` provides analysis-of-deviance Type I (sequential) tests for each dichotomy and for the combined model. When given a sequence of model objects, `anova()` tests the models against one another in the order specified.
* `Anova()` uses `car::Anova()` to provide analysis-of-deviance Type II or III (partial) tests for each dichotomy and for the combined model.
* `linearHypothesis()` uses `car::linearHypothesis()` to compute Wald tests for hypotheses about coefficients or their linear combinations.
* `logLik()` returns the log-likelihood and degrees of freedom for the nested-dichotomies logit model.
* Through `logLik()`, the `AIC()` and `BIC()` functions compute the Akaike and Bayesian information criteria model-comparison statistics.
* `RSQ()` computes a variety of pseudo $R^2$ (McFadden, CoxSnell, Nagelkerke, ...) measures for nested logit models.
